---
name: 💡 Feature request
about: Suggest an idea to improve Upkie
title: ''
labels: ''
assignees: ''

---

⚠️ **Please open a discussion in the [Ideas](https://github.com/robot-descriptions/robot_descriptions.py/discussions/categories/ideas) forum rather than an issue.**

Make sure your proposal checks out the following questions:

- [ ] Is your feature request related to a problem? Please describe, *e.g.* "I'm always frustrated when..."
- [ ] Describe (concisely) the solution you'd like.
- [ ] Describe alternatives you've considered.
- [ ] Do you have screenshots or sketches to illustrate your proposal?
